#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_pluralsight
----------------------------------

Tests for `pluralsight` module.

This does nothing, its a placeholder
"""

import unittest


class TestPluralsight(unittest.TestCase):

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_000_something(self):
        pass


if __name__ == '__main__':
    import sys
    sys.exit(unittest.main())
